unit TrekAngle;

{**********************************************************}
{                                                          }
{  TTrekAngle Unit                                         }
{  Copyright 1999 Workshell Software.                     }
{							   }
{  Version 1.0						   }
{                                                          }
{                                                          }
{  Web      -> http://www.workshell.uni.cc/                }
{  E - Mail -> trekvcl@kinsella.u-net.com                  }
{                                                          }
{**********************************************************}

interface

{$I TrekVer.inc}

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs;

type
 TAngleLayout = (alTopLeft, alBottomLeft, alTopRight, alBottomRight);

type
  TTrekAngle = class(TCustomControl)
  private
    { Private declarations }
    FColor: TColor;
    FBorderColor: TColor;
    FBackgroundColor: TColor;
    FLayout: TAngleLayout;
    FOnMouseEnter: TNotifyEvent;
    FOnMouseLeave: TNotifyEvent;
    procedure SetColor(Value: TColor);
    procedure SetBorderColor(Value: TColor);
    procedure SetBackgroundColor(Value: TColor);
    procedure SetLayout(Value: TAngleLayout);
    procedure CMMouseEnter(var Message: TMessage); message CM_MOUSEENTER;
    procedure CMMouseLeave(var Message: TMessage); message CM_MOUSELEAVE;
  protected
    { Protected declarations }
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    procedure Paint; override;
  public
    { Public declarations }
  published
    { Published declarations }
    property Color: TColor read FColor write SetColor;
    property BorderColor: TColor read FBorderColor write SetBorderColor;
    property BackgroundColor: TColor read FBackgroundColor write SetBackgroundColor;
    property Layout: TAngleLayout read FLayout write SetLayout;
    property OnMouseEnter: TNotifyEvent read FOnMouseEnter write FOnMouseEnter;
    property OnMouseLeave: TNotifyEvent read FOnMouseLeave write FOnMouseLeave;
    property Align;
    property Enabled;
    property OnClick;
    property OnDblClick;
    property OnMouseDown;
    property OnMouseUp;
    property OnMouseMove;
   {$IFDEF D4CB4}
    property Anchors;
    property BiDiMode;
    property Constraints;
    property DragKind;
    property ParentBiDiMode;
    property OnEndDock;
    property OnStartDock;
   {$ENDIF}
  end;

procedure Register;

implementation

constructor TTrekAngle.Create(AOwner: TComponent);
begin
 inherited Create(AOwner);
  Width := 65;
  Height := 65;
  Color := $0057D1FF;
  BorderColor := $0057D1FF;
  BackgroundColor := clBlack;
  Layout := alTopLeft;
  ControlStyle := [csAcceptsControls, csCaptureMouse, csClickEvents,
  csOpaque, csDoubleClicks, csReplicatable];
end;

destructor TTrekAngle.Destroy;
begin
 inherited Destroy;
end;

procedure TTrekAngle.Paint;
var
 Bitmap: TBitmap;
begin
Bitmap := TBitmap.Create;
Bitmap.Width := Width;
Bitmap.Height := Height;
with Bitmap.Canvas do
 begin
  Brush.Color := FBackgroundColor;
  FillRect(Rect(0,0,Width,Height));
  Pen.Color := FBorderColor;
  Brush.Color := FColor;
  if FLayout = alTopLeft then
   begin
    Ellipse(0,0,Width + Width,Height + Height);
    MoveTo(Width - 1,0);
    LineTo(Width - 1,Height);
    MoveTo(0,Height - 1);
    LineTo(Width,Height - 1);
   end;
  if FLayout = alBottomLeft then
   begin
    Ellipse(0,0 - Height,Width + Width,Height);
    MoveTo(0,0);
    LineTo(Width,0);
    MoveTo(Width - 1,0);
    LineTo(Width - 1,Height);
   end;
  if FLayout = alTopRight then
   begin
    Ellipse(0 - Width,0,Width,Height + Height);
    MoveTo(0,0);
    LineTo(0,Height);
    MoveTo(0,Height - 1);
    LineTo(Width,Height - 1);
   end;
  if FLayout = alBottomRight then
   begin
    Ellipse(0 - Width,0 - Height,Width,Height);
    MoveTo(0,0);
    LineTo(Width,0);
    MoveTo(0,0);
    LineTo(0,Height);
   end;
 end;
Canvas.CopyMode := cmSrcCopy;
Canvas.Draw(0,0, Bitmap);
Bitmap.Free;
end;

procedure TTrekAngle.SetColor(Value: TColor);
begin
 FColor := Value;
 Repaint;
end;

procedure TTrekAngle.SetBorderColor(Value: TColor);
begin
 FBorderColor := Value;
 Repaint;
end;

procedure TTrekAngle.SetBackgroundColor(Value: TColor);
begin
 FBackgroundColor := Value;
 Repaint;
end;

procedure TTrekAngle.SetLayout(Value: TAngleLayout);
begin
 FLayout := Value;
 Repaint;
end;

procedure TTrekAngle.CMMouseEnter(var Message: TMessage);
begin
if not (csDesigning in ComponentState) and (Enabled = True) then
 begin
  if Assigned(FOnMouseEnter) then FOnMouseEnter(Self);
 end;
end;

procedure TTrekAngle.CMMouseLeave(var Message: TMessage);
begin
if not (csDesigning in ComponentState) and (Enabled = True) then
 begin
  if Assigned(FOnMouseLeave) then FOnMouseLeave(Self);
 end;
end;

procedure Register;
begin
 RegisterComponents('StarTrek',[TTrekAngle]);
end;

end.
